.. py:module:: momotor.shared.exlock

=========================
``momotor.shared.exlock``
=========================

Implementation of an exclusive lock.

A subclass of `aiorwlock.RWLock <https://github.com/aio-libs/aiorwlock>`_

Class documentation
===================

.. autoclass:: momotor.shared.exlock.ExLock
   :members:
   :inherited-members:
